@@ -23,7 +23,7 @@
 #include <config.h>
 
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/connection.h>
@@ -154,6 +154,7 @@ tp_contact_list_group_member_removed_cb (EmpathyTpGroup       *group,
 			empathy_contact_get_id (contact),
 			empathy_contact_get_handle (contact),
 			group_name);
+		g_free (l->data);
 		*groups = g_list_delete_link (*groups, l);
 		g_signal_emit_by_name (list, "groups-changed", contact,
 				       group_name,
@@ -711,7 +712,7 @@ tp_contact_list_constructed (GObject *list)
 	const gchar              *protocol_name;
 
 	/* Get the connection. status==0 means CONNECTED */
-	mc = empathy_mission_control_new ();
+	mc = empathy_mission_control_dup_singleton ();
 	status = mission_control_get_connection_status (mc, priv->account, NULL);
 	g_return_if_fail (status == 0);
 	priv->connection = mission_control_get_tpconnection (mc, priv->account, NULL);
@@ -1103,3 +1104,19 @@ tp_contact_list_iface_init (EmpathyContactListIface *iface)
 	iface->remove_group	 = tp_contact_list_remove_group;
 }
 
+gboolean
+empathy_tp_contact_list_can_add (EmpathyTpContactList *list)
+{
+	EmpathyTpContactListPriv *priv;
+	TpChannelGroupFlags       flags;
+
+	g_return_val_if_fail (EMPATHY_IS_TP_CONTACT_LIST (list), FALSE);
+
+	priv = GET_PRIV (list);
+
+	if (priv->subscribe == NULL)
+		return FALSE;
+
+	flags = empathy_tp_group_get_flags (priv->subscribe);
+	return (flags & TP_CHANNEL_GROUP_FLAG_CAN_ADD) != 0;
+}
