@@ -144,7 +144,7 @@ empathy_tube_handler_init (EmpathyTubeHandler *thandler)
 }
 
 EmpathyTubeHandler *
-empathy_tube_handler_new (EmpathyTubeType type, const gchar *service)
+empathy_tube_handler_new (TpTubeType type, const gchar *service)
 {
   EmpathyTubeHandler *thandler = NULL;
   DBusGProxy *proxy;
@@ -153,7 +153,7 @@ empathy_tube_handler_new (EmpathyTubeType type, const gchar *service)
   gchar *object_path;
   GError *error = NULL;
 
-  g_return_val_if_fail (type <= EMPATHY_TYPE_DBUS_TUBE, NULL);
+  g_return_val_if_fail (type < NUM_TP_TUBE_TYPES, NULL);
   g_return_val_if_fail (service != NULL, NULL);
 
   bus_name = empathy_tube_handler_build_bus_name (type, service);
@@ -172,6 +172,7 @@ empathy_tube_handler_new (EmpathyTubeType type, const gchar *service)
       goto OUT;
     }
 
+  DEBUG ("Creating tube handler %s", bus_name);
   thandler = g_object_new (EMPATHY_TYPE_TUBE_HANDLER, NULL);
   dbus_g_connection_register_g_object (tp_get_bus (), object_path,
       G_OBJECT (thandler));
@@ -185,18 +186,18 @@ OUT:
 }
 
 gchar *
-empathy_tube_handler_build_bus_name (EmpathyTubeType type,
+empathy_tube_handler_build_bus_name (TpTubeType type,
   const gchar *service)
 {
   gchar *str = NULL;
   const gchar *prefix = NULL;
 
-  g_return_val_if_fail (type <= EMPATHY_TYPE_DBUS_TUBE, NULL);
+  g_return_val_if_fail (type < NUM_TP_TUBE_TYPES, NULL);
   g_return_val_if_fail (service != NULL, NULL);
 
-  if (type == EMPATHY_TYPE_DBUS_TUBE)
+  if (type == TP_TUBE_TYPE_DBUS)
     prefix = "org.gnome.Empathy.DTubeHandler.";
-  else if (type == EMPATHY_TYPE_STREAM_TUBE)
+  else if (type == TP_TUBE_TYPE_STREAM)
     prefix = "org.gnome.Empathy.StreamTubeHandler.";
   else
     g_return_val_if_reached (NULL);
@@ -207,13 +208,13 @@ empathy_tube_handler_build_bus_name (EmpathyTubeType type,
 }
 
 gchar *
-empathy_tube_handler_build_object_path (EmpathyTubeType type,
+empathy_tube_handler_build_object_path (TpTubeType type,
   const gchar *service)
 {
   gchar *bus_name;
   gchar *str;
 
-  g_return_val_if_fail (type <= EMPATHY_TYPE_DBUS_TUBE, NULL);
+  g_return_val_if_fail (type < NUM_TP_TUBE_TYPES, NULL);
   g_return_val_if_fail (service != NULL, NULL);
 
   bus_name = empathy_tube_handler_build_bus_name (type, service);
